@@ -90,6 +90,7 @@ NULL
 #' @slot override Used to prevent accidental use of memory intensive functions
 #' @slot solver Controls the linear solver used for relevant metrics
 #' @slot threads Used for multi-threading
+#' @slot precision "single" or "double". Only applies to convolution currently.
 #' @slot .cache Cached data for performance boosts
 
 setClass(
@@ -110,6 +111,7 @@ setClass(
                override = "logical",
                solver = "character",
                threads = "numeric",
+               precision = "character",
                .cache = "environment")
 
   # set default values
