@@ -14,11 +14,15 @@ Rcpp::XPtr<SolverCache> solver_cache()
   return ptr;
 }
 
-void SolverCache::buildSolver(const Eigen::SparseMatrix<double> &M, const std::string &fun)
+void SolverCache::buildSolver(const Eigen::SparseMatrix<double> &M,
+                              const std::string &fun)
 {
-  if (name != fun)
-  {
+  if (name != fun) {
     m_solver.compute(M);
+    if (m_solver.info() != Eigen::Success) {
+      Rcpp::stop("Solver failed in buildSolver");
+    }
+
     name = fun;
   }
 }
