@@ -6,9 +6,9 @@
 
 #include "solver-cache.h"
 
-
 // [[Rcpp::export(".f1")]]
-Rcpp::NumericVector f1(Eigen::Map<Eigen::SparseMatrix<double> > &M, Rcpp::XPtr<SolverCache> &SC)
+Rcpp::NumericVector f1(const Eigen::Map<Eigen::SparseMatrix<double> > &M,
+                       Rcpp::XPtr<SolverCache> &SC)
 {
   Eigen::VectorXd one(M.rows());
   one.fill(1.0);
@@ -16,12 +16,15 @@ Rcpp::NumericVector f1(Eigen::Map<Eigen::SparseMatrix<double> > &M, Rcpp::XPtr<S
   SC->buildSolver(M, "m");
 
   Eigen::VectorXd res = SC->solver().solve(one);
+  if(SC->solver().info() != Eigen::Success) {
+    Rcpp::stop("Solver failed in f1");
+  }
 
   return Rcpp::wrap(res);
 }
 
 // [[Rcpp::export(".f1_iter")]]
-Rcpp::NumericVector f1_iter(Eigen::Map<Eigen::SparseMatrix<double> > &M)
+Rcpp::NumericVector f1_iter(const Eigen::Map<Eigen::SparseMatrix<double> > &M)
 {
   Eigen::VectorXd one(M.rows());
   one.fill(1.0);
@@ -29,8 +32,14 @@ Rcpp::NumericVector f1_iter(Eigen::Map<Eigen::SparseMatrix<double> > &M)
   Eigen::BiCGSTAB<Eigen::SparseMatrix<double>, Eigen::IncompleteLUT<double> > solver;
 
   solver.compute(M);
+  if(solver.info() != Eigen::Success) {
+    Rcpp::stop("Decomposition failed in f1_iter");
+  }
 
   Eigen::VectorXd res = solver.solve(one);
+  if(solver.info() != Eigen::Success) {
+    Rcpp::stop("Solver failed in f1_iter");
+  }
 
   return Rcpp::wrap(res);
 }
